@@ -23,7 +23,7 @@ from functools import lru_cache, reduce, partial
 from itertools import tee, groupby
 from types import ModuleType
 from typing import (
-    cast, Callable, Dict, Generator, Iterable, List, Mapping, Optional, Set, Tuple,
+    cast, Any, Callable, Dict, Generator, Iterable, List, Mapping, Optional, Set, Tuple,
     Type, TypeVar, Union,
 )
 from warnings import warn
@@ -100,11 +100,7 @@ def reset():
                 method.cache_clear()
 
 
-def _render_template(template_name, **kwargs):
-    """
-    Returns the Mako template with the given name.  If the template
-    cannot be found, a nicer error message is displayed.
-    """
+def _get_config(**kwargs):
     # Apply config.mako configuration
     MAKO_INTERNALS = Template('').module.__dict__.keys()
     DEFAULT_CONFIG = path.join(path.dirname(__file__), 'templates', 'config.mako')
@@ -114,14 +110,32 @@ def _render_template(template_name, **kwargs):
         config.update((var, getattr(config_module, var, None))
                       for var in config_module.__dict__
                       if var not in MAKO_INTERNALS)
+
     known_keys = (set(config)
                   | {'docformat'}  # Feature. https://github.com/pdoc3/pdoc/issues/169
-                  | {'module', 'modules', 'http_server', 'external_links'})  # deprecated
+                  # deprecated
+                  | {'module', 'modules', 'http_server', 'external_links', 'search_query'})
     invalid_keys = {k: v for k, v in kwargs.items() if k not in known_keys}
     if invalid_keys:
         warn('Unknown configuration variables (not in config.mako): {}'.format(invalid_keys))
     config.update(kwargs)
 
+    if 'search_query' in config:
+        warn('Option `search_query` has been depricated, use `google_search_query` instead',
+             DeprecationWarning, stacklevel=2)
+        config['google_search_query'] = config['search_query']
+        del config['search_query']
+
+    return config
+
+
+def _render_template(template_name, **kwargs):
+    """
+    Returns the Mako template with the given name.  If the template
+    cannot be found, a nicer error message is displayed.
+    """
+    config = _get_config(**kwargs)
+
     try:
         t = tpl_lookup.get_template(template_name)
     except TopLevelLookupException:
@@ -882,6 +896,34 @@ class Module(Doc):
         return url + _URL_MODULE_SUFFIX
 
 
+def _getmembers_all(obj: type) -> List[Tuple[str, Any]]:
+    # The following code based on inspect.getmembers() @ 5b23f7618d43
+    mro = obj.__mro__[:-1]  # Skip object
+    names = set(dir(obj))
+    # Add keys from bases
+    for base in mro:
+        names.update(base.__dict__.keys())
+    # Add members for which type annotations exist
+    names.update(_get_type_hints(obj).keys())
+
+    results = []
+    for name in names:
+        try:
+            value = getattr(obj, name)
+        except AttributeError:
+            for base in mro:
+                if name in base.__dict__:
+                    value = base.__dict__[name]
+                    break
+            else:
+                # Missing slot member or a buggy __dir__;
+                # In out case likely a type-annotated member
+                # which we'll interpret as a variable
+                value = None
+        results.append((name, value))
+    return results
+
+
 class Class(Doc):
     """
     Representation of a class' documentation.
@@ -902,14 +944,31 @@ class Class(Doc):
         self.doc = {}  # type: Dict[str, Union[Function, Variable]]
         """A mapping from identifier name to a `pdoc.Doc` objects."""
 
+        # Annotations for filtering.
+        # Use only own, non-inherited annotations (the rest will be inherited)
+        annotations = getattr(self.obj, '__annotations__', {})
+
         public_objs = [(_name, inspect.unwrap(obj))
-                       for _name, obj in inspect.getmembers(self.obj)
+                       for _name, obj in _getmembers_all(self.obj)
                        # Filter only *own* members. The rest are inherited
                        # in Class._fill_inheritance()
-                       if _name in self.obj.__dict__
+                       if (_name in self.obj.__dict__ or _name in annotations)
                        and (_is_public(_name) or _is_whitelisted(_name, self))]
-        index = list(self.obj.__dict__).index
-        public_objs.sort(key=lambda i: index(i[0]))
+
+        def definition_order_index(
+                name,
+                _annot_index=list(annotations).index,
+                _dict_index=list(self.obj.__dict__).index):
+            try:
+                return _dict_index(name)
+            except ValueError:
+                pass
+            try:
+                return _annot_index(name) - len(annotations)  # sort annotated first
+            except ValueError:
+                return 9e9
+
+        public_objs.sort(key=lambda i: definition_order_index(i[0]))
 
         var_docstrings, instance_var_docstrings = _pep224_docstrings(self)
 
@@ -1242,7 +1301,18 @@ class Function(Doc):
     @staticmethod
     def _params(doc_obj, annotate=False, link=None, module=None):
         try:
-            signature = inspect.signature(doc_obj.obj)
+            # We want __init__ to actually be implemented somewhere in the
+            # MRO to still satisfy https://github.com/pdoc3/pdoc/issues/124
+            if (
+                inspect.isclass(doc_obj.obj)
+                and doc_obj.obj.__init__ is not object.__init__
+            ):
+                # Remove the first argument (self) from __init__ signature
+                init_sig = inspect.signature(doc_obj.obj.__init__)
+                init_params = list(init_sig.parameters.values())
+                signature = init_sig.replace(parameters=init_params[1:])
+            else:
+                signature = inspect.signature(doc_obj.obj)
         except ValueError:
             signature = Function._signature_from_string(doc_obj)
             if not signature:
