@@ -36,6 +36,8 @@ EXAMPLE_MODULE = 'example_pkg'
 
 sys.path.insert(0, TESTS_BASEDIR)
 
+T = typing.TypeVar("T")
+
 
 @contextmanager
 def temp_dir():
@@ -241,6 +243,17 @@ class CliTest(unittest.TestCase):
             self._basic_html_assertions()
             self._check_files(exclude_patterns=['class="source"', 'Hidden'])
 
+    def test_html_with_google(self):
+        with run_html(EXAMPLE_MODULE, config='google_search_query="anything"'):
+            self._basic_html_assertions()
+            self._check_files(include_patterns=['class="gcse-search"'])
+
+    def test_html_with_lunr(self):
+        with run_html(EXAMPLE_MODULE, config='lunr_search={"fuzziness": 1}'):
+            files = self.PUBLIC_FILES + ["example_pkg/search.html", "example_pkg/index.js"]
+            self._basic_html_assertions(expected_files=files)
+            self._check_files(exclude_patterns=['class="gcse-search"'])
+
     def test_force(self):
         with run_html(EXAMPLE_MODULE):
             with redirect_streams() as (stdout, stderr):
@@ -901,12 +914,23 @@ class Foo:
             def __init__(self):
                 """baz"""
 
+        class F(typing.Generic[T]):
+            """baz"""
+
+            def __init__(self):
+                """bar"""
+
+        class G(F[int]):
+            """foo"""
+
         mod = pdoc.Module(pdoc)
         self.assertEqual(pdoc.Class('A', mod, A).docstring, """foo""")
         self.assertEqual(pdoc.Class('B', mod, B).docstring, """foo""")
         self.assertEqual(pdoc.Class('C', mod, C).docstring, """foo\n\nbar""")
         self.assertEqual(pdoc.Class('D', mod, D).docstring, """baz\n\nbar""")
         self.assertEqual(pdoc.Class('E', mod, E).docstring, """foo\n\nbaz""")
+        self.assertEqual(pdoc.Class('F', mod, F).docstring, """baz\n\nbar""")
+        self.assertEqual(pdoc.Class('G', mod, G).docstring, """foo\n\nbar""")
 
     @ignore_warnings
     def test_Class_params(self):
@@ -925,6 +949,17 @@ class Foo:
 
         self.assertEqual(pdoc.Class('C2', mod, C2).params(), ['a', 'b', 'c=None', '*', 'd=1', 'e'])
 
+        class G(typing.Generic[T]):
+            def __init__(self, a, b, c=100):
+                pass
+
+        self.assertEqual(pdoc.Class('G', mod, G).params(), ['a', 'b', 'c=100'])
+
+        class G2(typing.Generic[T]):
+            pass
+
+        self.assertEqual(pdoc.Class('G2', mod, G2).params(), ['*args', '**kwds'])
+
     def test_url(self):
         mod = pdoc.Module(EXAMPLE_MODULE)
         pdoc.link_inheritance()
@@ -972,6 +1007,31 @@ class Foo:
         self.assertEqual(mod.name, 'pdoc')
         self.assertIn('Module', mod.doc)
 
+    @ignore_warnings
+    @unittest.skipIf(sys.version_info < (3, 6), 'variable type annotation unsupported in <Py3.6')
+    def test_class_members(self):
+        module = pdoc.Module(EXAMPLE_MODULE)
+
+        # GH-200
+        from enum import Enum
+
+        class Tag(Enum):
+            Char = 1
+
+            def func(self):
+                return self
+
+        cls = pdoc.Class('Tag', module, Tag)
+        self.assertIsInstance(cls.doc['Char'], pdoc.Variable)
+        self.assertIsInstance(cls.doc['func'], pdoc.Function)
+
+        # GH-210, GH-212
+        my_locals = {}
+        exec('class Employee:\n name: str', my_locals)
+        cls = pdoc.Class('Employee', module, my_locals['Employee'])
+        self.assertIsInstance(cls.doc['name'], pdoc.Variable)
+        self.assertEqual(cls.doc['name'].type_annotation(), 'str')
+
 
 class HtmlHelpersTest(unittest.TestCase):
     """
@@ -1285,7 +1345,7 @@ that are relevant to the interface.</p>
 </dl>
 <h2 id="examples">Examples</h2>
 <p>Examples in doctest format.</p>
-<pre><code class="python">&gt;&gt;&gt; a = [1,2,3]
+<pre><code class="python-repl">&gt;&gt;&gt; a = [1,2,3]
 </code></pre>
 
 <h2 id="todos">Todos</h2>
@@ -1309,20 +1369,20 @@ always
 </code></pre>
 
 <h2 id="examples">Examples</h2>
-<pre><code class="python">&gt;&gt;&gt; nbytes(100)
+<pre><code class="python-repl">&gt;&gt;&gt; nbytes(100)
 '100.0 bytes'
 line2
 </code></pre>
 
 <p>some text</p>
 <p>some text</p>
-<pre><code class="python">&gt;&gt;&gt; another doctest
+<pre><code class="python-repl">&gt;&gt;&gt; another doctest
 line1
 line2
 </code></pre>
 
 <h2 id="example">Example</h2>
-<pre><code class="python">&gt;&gt;&gt; f()
+<pre><code class="python-repl">&gt;&gt;&gt; f()
 Traceback (most recent call last):
     ...
 Exception: something went wrong
